@@ -5,26 +5,14 @@ from pydantic import BaseModel
 from pydantic import ValidationError as PydanticValidationError
 from pydantic import create_model
 from pydantic.error_wrappers import ErrorWrapper
-from starlette.exceptions import HTTPException
+from starlette.exceptions import HTTPException as HTTPException  # noqa: F401
 from starlette.status import HTTP_422_UNPROCESSABLE_ENTITY
 
-__all__ = (
-    "XpressoError",
-    "HTTPException",
-    "RequestValidationError",
-    "WebSocketValidationError",
-)
-
-
-class XpressoError(Exception):
-    ...
-
-
 _RequestErrorModel: Type[BaseModel] = create_model("Request")  # type: ignore
 _WebSocketErrorModel: Type[BaseModel] = create_model("WebSocket")  # type: ignore
 
 
-class RequestValidationError(PydanticValidationError, XpressoError):
+class RequestValidationError(PydanticValidationError):
     raw_errors: List[ErrorWrapper]
 
     def __init__(
@@ -36,7 +24,7 @@ class RequestValidationError(PydanticValidationError, XpressoError):
         self.status_code = status_code
 
 
-class WebSocketValidationError(PydanticValidationError, XpressoError):
+class WebSocketValidationError(PydanticValidationError):
     def __init__(
         self,
         errors: typing.Sequence[ErrorWrapper],
